@@ -25,10 +25,22 @@ def export_nc(geom, metadata, alpha, wave, snr_factor, wct_peak_margin, ltool_ve
     geom_dts.attrs['processor_version'] = ltool_ver
     
     time = datetime.datetime.now().strftime('%Y-%m-%dT%H:%M:%SZ')
-    args = ' '.join(sys.argv[1:])
+
+    argv = sys.argv
+    argv[-1] = os.path.basename(argv[-1])
+    args = ' '.join(argv[1:])
     geom_dts.attrs['history'] = f"{geom_dts.attrs['history']}; {time}: ltool {args}" 
+
     geom_dts.attrs['layer_method'] = 'Wavelet Correlation Transform'
     
+    
+    ssc_vd = geom_dts.attrs['scc_version_description']
+    parts = ssc_vd.split(')')
+    ssc_vd = f'{parts[0]}, LTOOL vers. {ltool_ver}){parts[-1]}'
+    geom_dts.attrs['scc_version_description'] = ssc_vd
+    
+    geom_dts.attrs['__file_format_version'] = '1.0'
+    
     if snr_factor != snr_factor:
         snr_factor = netCDF4.default_fillvals['f8']
     geom_dts['snr_factor'] = snr_factor
